==> peg-e_1.1.2.orig.tar.bz2: peg-e-1.1.2/translations/pege_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="193"/>
        <source>Game Over</source>
        <translation>Einde spel</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Selecteer programma taal:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>Systeem Taal</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Note</source>
        <translation>Noteren</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="181"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstarten van programma is nodig om van taal te veranderen.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="49"/>
        <location filename="../src/window.cpp" line="246"/>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="58"/>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="62"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>&amp;Restart Game</source>
        <translation>&amp;Herstart Spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="66"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="68"/>
        <source>&amp;Details</source>
        <translation>&amp;Informatie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Quit</source>
        <translation>Einde</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="74"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="76"/>
        <source>&amp;Move</source>
        <translation>&amp;Verplaats</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>Ctrl+z</source>
        <translation>Ctrl+z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>&amp;Redo</source>
        <translation>&amp;Opnieuw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="86"/>
        <source>Shift+Ctrl+Z</source>
        <translation>Shift+Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="90"/>
        <source>&amp;Appearance</source>
        <translation>&amp;Uiterlijk</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="93"/>
        <source>Blue</source>
        <translation>Blauw</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="94"/>
        <source>Charcoal</source>
        <translation>Houtskool</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>Green</source>
        <translation>Groen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="96"/>
        <source>Midnight</source>
        <translation>Donkerzwart</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Plum</source>
        <translation>Paars</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="98"/>
        <source>Red</source>
        <translation>Rood</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="99"/>
        <source>Yellow</source>
        <translation>Geel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="117"/>
        <source>Custom...</source>
        <translation>Gebruik...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="119"/>
        <source>&amp;Settings</source>
        <translation>&amp;Instelling</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>Application &amp;Language...</source>
        <translation>Programma &amp;Taal...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="124"/>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>New Game</source>
        <translation>Nieuw Spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <location filename="../src/window.cpp" line="225"/>
        <location filename="../src/window.cpp" line="317"/>
        <source>Original</source>
        <translation>Orgineel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="166"/>
        <location filename="../src/window.cpp" line="218"/>
        <location filename="../src/window.cpp" line="320"/>
        <source>Branch</source>
        <translation>Afdeling</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="167"/>
        <location filename="../src/window.cpp" line="221"/>
        <location filename="../src/window.cpp" line="323"/>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Random</source>
        <translation>Willekeurige</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="186"/>
        <source>Algorithm:</source>
        <translation>Algoritme:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="187"/>
        <source>Difficulty:</source>
        <translation>Moeilijkheid:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="188"/>
        <source>Seed:</source>
        <translation>Seed:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="205"/>
        <source>Do you want to restart?</source>
        <translation>Wil je herstarten?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Details</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algoritme:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Moeilijkheid:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="243"/>
        <source>About Peg-E</source>
        <translation>Over Peg-E</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="247"/>
        <source>Peg elimination game</source>
        <translation>Peg eliminatie spel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="248"/>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copy;2012-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="249"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onde de &lt;a href=%1&gt;GPL 3&lt;/a&gt; overeenkomst</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="250"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Gebruik iconen van de &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon onderwerp</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="251"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;OLGPL 3&lt;/a&gt; overeenkomst</translation>
    </message>
</context>
</TS>

==> peg-e-1.3.5.tar.bz2: peg-e-1.3.5/translations/pege_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Einde spel</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecteer programma taal:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Noteren</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Herstarten van programma is nodig om van taal te veranderen.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>&amp;Herstart Spel</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Informatie</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Einde</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Verplaats</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Opnieuw</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>&amp;Uiterlijk</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blauw</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>Houtskool</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Groen</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>Donkerzwart</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>Paars</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rood</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Geel</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Gebruik...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instelling</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programma &amp;Taal...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Over &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Nieuw Spel</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>Orgineel</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>Afdeling</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Willekeurige</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritme:</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>Moeilijkheid:</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>Seed:</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>Wil je herstarten?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Algoritme:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Moeilijkheid:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>Over Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>Peg eliminatie spel</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Auteursrecht &amp;copy;2012-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Uitgebracht onde de &lt;a href=%1&gt;GPL 3&lt;/a&gt; overeenkomst</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Gebruik iconen van de &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon onderwerp</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Gebruikt onder de &lt;a href=%1&gt;OLGPL 3&lt;/a&gt; overeenkomst</translation>
    </message>
</context>
</TS>
